@@ -1,7 +1,5 @@
-import json
 import datetime
 import logging
-import re
 from typing import Optional
 
 import pytz
@@ -44,27 +42,13 @@ class SiweBackend(BaseBackend):
     Authenticate an Ethereum address as per Sign-In with Ethereum (EIP-4361).
     """
 
-    def authenticate(self, request, signature: str = None, siwe_message: SiweMessage = None):
-        body = json.loads(request.body)
-
-        if siwe_message is None:
-            siwe_message = SiweMessage(
-                message={
-                    re.sub(r"(?<!^)(?=[A-Z])", "_", k).lower(): v
-                    for k, v in body["message"].items()
-                }
-            )
-            signature = body["signature"]
-
+    def authenticate(self, request, signature: str, siwe_message: SiweMessage):
         # Validate signature
         w3 = Web3(HTTPProvider(settings.PROVIDER))
         w3.middleware_onion.inject(geth_poa_middleware, layer=0)
 
         try:
             siwe_message.validate(signature=signature, provider=w3)
-        except ValidationError:
-            logging.info("Authentication attempt rejected due to invalid message.")
-            return None
         except ExpiredMessage:
             logging.info("Authentication attempt rejected due to expired message.")
             return None
@@ -76,6 +60,9 @@ class SiweBackend(BaseBackend):
         except InvalidSignature:
             logging.info("Authentication attempt rejected due to invalid signature.")
             return None
+        except ValidationError:
+            logging.info("Authentication attempt rejected due to invalid message.")
+            return None
 
         # Validate nonce
         if not _nonce_is_valid(siwe_message.nonce):
